==> jc-1.4.0.tar.gz: java/util/Collections__24SynchronizedSet.h <==
// class java.util.Collections$SynchronizedSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 49021d874f7b140b java_util_Collections__24SynchronizedCollection
// @dep_class b10c6bbe8b325c8b java_util_Collections__24SynchronizedSet

// header file dependencies
// @dep_header java_util_Collections__24SynchronizedCollection

#include "java/util/Collections__24SynchronizedCollection.h"

#ifndef _JC_java_util_Collections__24SynchronizedSet_H_
#define _JC_java_util_Collections__24SynchronizedSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_java_util_Collections__24SynchronizedSet$sub_refs	_jc_java_util_Collections__24SynchronizedSet$sub_refs;
typedef struct _jc_java_util_Collections__24SynchronizedSet$sub_nonrefs	_jc_java_util_Collections__24SynchronizedSet$sub_nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedSet$refs	_jc_java_util_Collections__24SynchronizedSet$refs;
typedef struct _jc_java_util_Collections__24SynchronizedSet$nonrefs	_jc_java_util_Collections__24SynchronizedSet$nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedSet$object	_jc_java_util_Collections__24SynchronizedSet$object;

typedef struct _jc_java_util_Collections__24SynchronizedSet$fields_struct	_jc_java_util_Collections__24SynchronizedSet$fields_struct;
typedef const struct _jc_java_util_Collections__24SynchronizedSet$vmethods	_jc_java_util_Collections__24SynchronizedSet$vmethods;
typedef const struct _jc_java_util_Collections__24SynchronizedSet$vtable	_jc_java_util_Collections__24SynchronizedSet$vtable;
typedef const struct _jc_java_util_Collections__24SynchronizedSet$vtype	_jc_java_util_Collections__24SynchronizedSet$vtype;

// Class fields structure
struct _jc_java_util_Collections__24SynchronizedSet$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24SynchronizedSet$fields_struct _jc_java_util_Collections__24SynchronizedSet$class_fields;

// Constructors
extern void _jc_java_util_Collections__24SynchronizedSet$method$_init$d65aa01c01a0df47(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSet$object *, struct _jc_java_lang_Object$object *, struct _jc_object *);
extern void _jc_java_util_Collections__24SynchronizedSet$method$_init$4239edc3ba8b9760(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSet$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_java_util_Collections__24SynchronizedSet$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSet$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_util_Collections__24SynchronizedSet$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSet$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24SynchronizedSet$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_util_Collections__24SynchronizedSet$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_java_util_Collections__24SynchronizedSet$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSet$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSet$object *);
};

// Vtable
struct _jc_java_util_Collections__24SynchronizedSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24SynchronizedCollection$vmethods	java_util_Collections__24SynchronizedCollection;
	_jc_java_util_Collections__24SynchronizedSet$vmethods	java_util_Collections__24SynchronizedSet;
};

// Vtype
struct _jc_java_util_Collections__24SynchronizedSet$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24SynchronizedSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedSet$refs {
    _jc_java_util_Collections__24SynchronizedSet$sub_refs	java_util_Collections__24SynchronizedSet;
    _jc_java_util_Collections__24SynchronizedCollection$sub_refs	java_util_Collections__24SynchronizedCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24SynchronizedCollection$sub_nonrefs	java_util_Collections__24SynchronizedCollection;
    _jc_java_util_Collections__24SynchronizedSet$sub_nonrefs	java_util_Collections__24SynchronizedSet;
};

// Object instance structure
struct _jc_java_util_Collections__24SynchronizedSet$object {
	_jc_java_util_Collections__24SynchronizedSet$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24SynchronizedSet$vtype	*vtype;
	_jc_java_util_Collections__24SynchronizedSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24SynchronizedSet$vtype _jc_java_util_Collections__24SynchronizedSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24SynchronizedSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24SynchronizedSet$class_object;

#endif	/* _JC_java_util_Collections__24SynchronizedSet_H_ */

==> jc-1.4.6.tar.gz: java/util/Collections__24SynchronizedSet.h <==
// class java.util.Collections$SynchronizedSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 49021d874f7b140b java_util_Collections__24SynchronizedCollection
// @dep_class b10c6bbe8b325c8b java_util_Collections__24SynchronizedSet

// header file dependencies
// @dep_header java_util_Collections__24SynchronizedCollection

#include "java/util/Collections__24SynchronizedCollection.h"

#ifndef _JC_java_util_Collections__24SynchronizedSet_H_
#define _JC_java_util_Collections__24SynchronizedSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_java_util_Collections__24SynchronizedSet$sub_refs	_jc_java_util_Collections__24SynchronizedSet$sub_refs;
typedef struct _jc_java_util_Collections__24SynchronizedSet$sub_nonrefs	_jc_java_util_Collections__24SynchronizedSet$sub_nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedSet$refs	_jc_java_util_Collections__24SynchronizedSet$refs;
typedef struct _jc_java_util_Collections__24SynchronizedSet$nonrefs	_jc_java_util_Collections__24SynchronizedSet$nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedSet$object	_jc_java_util_Collections__24SynchronizedSet$object;

typedef struct _jc_java_util_Collections__24SynchronizedSet$fields_struct	_jc_java_util_Collections__24SynchronizedSet$fields_struct;
typedef const struct _jc_java_util_Collections__24SynchronizedSet$vmethods	_jc_java_util_Collections__24SynchronizedSet$vmethods;
typedef const struct _jc_java_util_Collections__24SynchronizedSet$vtable	_jc_java_util_Collections__24SynchronizedSet$vtable;
typedef const struct _jc_java_util_Collections__24SynchronizedSet$vtype	_jc_java_util_Collections__24SynchronizedSet$vtype;

// Class fields structure
struct _jc_java_util_Collections__24SynchronizedSet$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24SynchronizedSet$fields_struct _jc_java_util_Collections__24SynchronizedSet$class_fields;

// Constructors
extern void _jc_java_util_Collections__24SynchronizedSet$method$_init$d65aa01c01a0df47(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSet$object *, struct _jc_java_lang_Object$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_util_Collections__24SynchronizedSet$method$_init$4239edc3ba8b9760(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSet$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_Collections__24SynchronizedSet$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_Collections__24SynchronizedSet$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSet$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24SynchronizedSet$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_util_Collections__24SynchronizedSet$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_java_util_Collections__24SynchronizedSet$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSet$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Collections__24SynchronizedSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24SynchronizedCollection$vmethods	java_util_Collections__24SynchronizedCollection;
	_jc_java_util_Collections__24SynchronizedSet$vmethods	java_util_Collections__24SynchronizedSet;
};

// Vtype
struct _jc_java_util_Collections__24SynchronizedSet$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24SynchronizedSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedSet$refs {
    _jc_java_util_Collections__24SynchronizedSet$sub_refs	java_util_Collections__24SynchronizedSet;
    _jc_java_util_Collections__24SynchronizedCollection$sub_refs	java_util_Collections__24SynchronizedCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24SynchronizedCollection$sub_nonrefs	java_util_Collections__24SynchronizedCollection;
    _jc_java_util_Collections__24SynchronizedSet$sub_nonrefs	java_util_Collections__24SynchronizedSet;
};

// Object instance structure
struct _jc_java_util_Collections__24SynchronizedSet$object {
	_jc_java_util_Collections__24SynchronizedSet$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24SynchronizedSet$vtype	*vtype;
	_jc_java_util_Collections__24SynchronizedSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24SynchronizedSet$vtype _jc_java_util_Collections__24SynchronizedSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24SynchronizedSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24SynchronizedSet$class_object;

#endif	/* _JC_java_util_Collections__24SynchronizedSet_H_ */
